\name{get.similarity.between.genes}
\alias{get.similarity.between.genes}

\title{Client-side interface to obtain the similarity value between two
  genes}
\description{
  Given two KEGG ids for genes, the function searches the KEGG GENES
  database to obtain a measure of the similarity between the two
  genes. The similarity between genes is determined by alignment of
  matching bases. 
}
\usage{
get.similarity.between.genes(genes.id1, genes.id2)
}

\arguments{
  \item{genes.id1}{\code{genes.id1} a character string for the id used by
    KEGG to represent the gene of interest. The id normally consists of
    three letters followed by a colon and then several numbers. The
    three letters are from the first letter of the genus 
    name and the first two letters of the species name of the scientific
    name of the organism of concern (e. g. hsa:111 for Homo Sapiens)}
  \item{genes.id2}{\code{genes.id2} same as \code{genes.id1} but for
    another gene}
}
\details{
  The corresponding KEGG SOAP method returns a list of data as described
  in the return list of
  \code{\link{get.best.neighbors.by.gene}}. \code{\link{get.similarity.between.genes}} extracts and returns the value for identity from the list. 
}
\value{
  This function returns a value between 0 and 1 for the protortion of
  matching bases between the two genes 
}
\references{\url{http://www.genome.jp/kegg/soap/doc/keggapi_manual.html}}
\author{Jianhua Zhang}

\seealso{\code{\link{get.neighbors.by.gene}}}
\examples{
    if(require("SSOAP") && require("XML")){
        get.similarity.between.genes("eco:b0002", "eco:b3940")
    }
}
\keyword{ datasets }

